==> haskell-ghcide-2.1.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-LeHVYn4xxzmCBlpdIjSTbW
key:                  ghcide-2.1.0.0-LeHVYn4xxzmCBlpdIjSTbW
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  855c83f3f7bcde1bc9eb09dc1c4002c6
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-LeHVYn4xxzmCBlpdIjSTbW
depends:
    Diff-0.4.1-KJ48I4npTFjHzRWUMxJmhj Glob-0.10.2-6HFwg9HAY2xXoaRcXZBQF
    aeson-2.1.2.1-4XssoWP8s0tKPHSv4bO4jS
    aeson-pretty-0.8.10-GulstWOdB24FAw6bDCaBa1 array-0.5.4.0
    async-2.2.5-75FFlJsh5XPALDlYx1XYqh base-4.17.2.1
    base16-bytestring-1.0.2.0-3RDvwOh55ot54GVXP1pwgX binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-DJzIJZH4DdL5KuISGpY4ML
    co-log-core-0.3.2.5-IBB9xtBNbvnLwqzeTgcBM7 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Jegj087crmF7dcbdZBbm3M
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy deepseq-1.4.8.0
    dependent-map-0.4.0.0-2qchZkvLBMyExyp2AzKjJF
    dependent-sum-0.7.2.0-Jy50GBt3iZR6Pc1dELvj8K directory-1.3.7.1
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN
    enummapset-0.7.3.0-84wDMSXPBTC8s1YnYDHJpa exceptions-0.10.5
    extra-1.7.16-FilKm1JQPfHLr5IAgySohi filepath-1.4.2.2
    fingertree-0.1.6.2-G4lCTwYHm9FB3JKTUhg9Vl
    focus-1.0.3.2-7dgq2c9qIidIgcP8J4mcYD ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-check-0.5.0.8-IoTwooEIr6c384iJvrwuRc
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-trace-events-0.1.2.9-7ocQkvnjYWsA9rDcBsLuv7
    haddock-library-1.11.0-HZcfp9xsR4BBABREczApx9
    hashable-1.4.4.0-D3m6G7BPJON5VQ2FLdROoK
    hie-bios-0.12.0-2cGeooxP7Fi2ocR5MDPGXn
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    hiedb-0.4.3.0-KXCYNN2TgFoOoXjpUIB2N
    hls-graph-2.1.0.0-1ahZHgPn9ld2Ni0PciEaLP
    hls-plugin-api-2.1.0.0-K4FbFqyLEJN6X72PrrNzeA
    implicit-hie-0.1.4.0-6oDYMpGOsw0rcIiRnijBz
    implicit-hie-cradle-0.5.0.1-94zFOckhU2K7MonEYXszzj
    lens-5.3.1-EJGBiJ62DpEHaBgUJVPkQg
    list-t-1.0.5.7-FmxShSn9yIY1oipxPqaSPU
    lsp-2.1.0.0-Ftv7hrNHdgW6IKFCFoXoOX
    lsp-types-2.0.1.0-2VjITqMTecEFKvXMh9RptU mtl-2.2.2
    opentelemetry-0.8.0-F2VfMR4X7EiVDidnQH0O0
    optparse-applicative-0.18.1.0-1qQAtHv6qKDHnowaperQhI
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-5ZQmBmwWcWI11K7a8GbhBl
    prettyprinter-ansi-terminal-1.1.3-BBtZEBIElqGhweUz6FSLq
    random-1.2.1.3-Hc2Rnu5BTd49WL1xp2j5Li
    regex-tdfa-1.3.2.4-EhX7jCEB4hYAzMd1ZradSc
    row-types-1.0.1.2-CapujoOQEDKDAPaDIV3CDS
    safe-exceptions-0.1.7.4-JyBwFDgk1shNJ63ukmgRM
    sorted-list-0.2.3.1-1ZkrlSOoT8zHrtcyGxL75w
    sqlite-simple-0.4.19.0-9PAPa6yeggFJjHLqLHRY1d stm-2.5.1.0
    stm-containers-1.2.1.1-Kje5NRkuAH1LXzXIPCHc0A
    syb-0.7.2.4-3MUyG3p3euQLeyQ65NE0AP text-2.0.2
    text-rope-0.3-7ntH37P22H1R37LmQKYzX time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-6hqRoAco5caH8WO2T8BxQ0
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-3371VA61Be1CojVrkG24uM
    vector-0.13.2.0-EWs7nDhBFQF5RfgCWU6KmC

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-2.1.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-1KOcaMBafULLEncWomo7Qk
key:                  ghcide-2.1.0.0-1KOcaMBafULLEncWomo7Qk
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  96a0820fcf400439672c9a08a828a772
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-1KOcaMBafULLEncWomo7Qk
depends:
    Diff-0.4.1-KLr9PfX1xcQ7rTrhHR462U
    Glob-0.10.2-5FHimdo10HkHvHZ1JWoCgP
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC
    aeson-pretty-0.8.10-tSS21E5UX6Le9dDEWI2uO array-0.5.4.0
    async-2.2.5-Fwc3ABGHG7o8WWC3l3QDRi base-4.17.2.1
    base16-bytestring-1.0.2.0-3kwon8iNzO25udiTa31L4P binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf
    co-log-core-0.3.2.5-7m6HuklLii64LMQ1MpN6iG containers-0.6.7
    cryptohash-sha1-0.11.101.0-GI8n52j9pytKz5kEzBvRkT
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy deepseq-1.4.8.0
    dependent-map-0.4.0.0-HTfacg3i7qQ29ogDz0x8On
    dependent-sum-0.7.2.0-Fgd8y1WDemz2U0Y3CJxhFC directory-1.3.7.1
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN
    enummapset-0.7.3.0-7Igm2APzhn56hhx08neE3D exceptions-0.10.5
    extra-1.7.16-3MpJB5o0ESB1pjz4ZT9XVu filepath-1.4.2.2
    fingertree-0.1.6.2-KgaN9n2WCbmStKKPC7nlw
    focus-1.0.3.2-KqKSvokHUTp3b3GkWDqnts ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-check-0.5.0.8-7rEtvrsxzIUHruE4Q5sXgj
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-trace-events-0.1.2.9-7ocQkvnjYWsA9rDcBsLuv7
    haddock-library-1.11.0-9E1OeIINBFV53JSwDDw830
    hashable-1.4.4.0-AmJtI56ndXc1GvGfBNNgwb
    hie-bios-0.12.0-2N0y5yLEsBi6uOFMcW3Qgf
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    hiedb-0.4.3.0-KcQoeOJJELA6JaEbOiH69f
    hls-graph-2.1.0.0-8gz4dmxk15l37hnwvJlpMG
    hls-plugin-api-2.1.0.0-KSS8kWBQYXNJC6hz6fAtRu
    implicit-hie-0.1.4.0-GKDBVxhPg0t6LcyFbMi6Et
    implicit-hie-cradle-0.5.0.1-84rG2ggGhYpEIk9gwd2bj9
    lens-5.3.1-LF4jCoE0w776e2gq32lhyl
    list-t-1.0.5.7-C6FGQIuzwiv1nPBm2mNdX9
    lsp-2.1.0.0-JpAybzOu2bA4LGzZcHHGTh
    lsp-types-2.0.1.0-CpSI1ypjR9r72V9wDhxm76 mtl-2.2.2
    opentelemetry-0.8.0-7H7OfRYQMGIH1O7PMChvpH
    optparse-applicative-0.18.1.0-B5S7p3yvcpkHKfw0kuCuBU
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-5xgqmGXqgSr2RPa1NTsZyQ
    prettyprinter-ansi-terminal-1.1.3-BMaxYpGY1hqAqhAfKIKQLq
    random-1.2.1.3-2cudg871s2f2tL4YjAU8WJ
    regex-tdfa-1.3.2.4-DzgOWHlgf3T5HZBC9uVz6f
    row-types-1.0.1.2-JUPGubFZ6cE3E4LlCuUdLY
    safe-exceptions-0.1.7.4-FCgyye4Wo0dEy8n60CbiPd
    sorted-list-0.2.3.1-GLhvvqV7QQD5fX9Krb1rr5
    sqlite-simple-0.4.19.0-7LXStB6sXEQIHpoNcT5ABP stm-2.5.1.0
    stm-containers-1.2.1.1-2lmgloSclqL5OCFBhypHc5
    syb-0.7.2.4-Au9jUQxtdeJGhFGXkWlbWz text-2.0.2
    text-rope-0.3-GDm3yeD8AoS1PxPruyvWGM time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-6SrDYM6H10EJJ9ZQAtB2Dj
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
